@@ -39,8 +39,11 @@ _DEFAULT_LOGGING_CONTEXT_FORMAT = ('%(asctime)s.%(msecs)03d %(process)d '
 def set_defaults(conf, backend=None, barbican_endpoint=None,
                  barbican_api_version=None, auth_endpoint=None,
                  retry_delay=None, number_of_retries=None, verify_ssl=None,
-                 api_class=None, vault_root_token_id=None, vault_url=None,
-                 vault_ssl_ca_crt_file=None, vault_use_ssl=None):
+                 api_class=None, vault_root_token_id=None,
+                 vault_approle_role_id=None, vault_approle_secret_id=None,
+                 vault_kv_mountpoint=None, vault_url=None,
+                 vault_ssl_ca_crt_file=None, vault_use_ssl=None,
+                 barbican_endpoint_type=None):
     """Set defaults for configuration values.
 
     Overrides the default options values.
@@ -53,9 +56,15 @@ def set_defaults(conf, backend=None, barbican_endpoint=None,
     :param number_of_retries: Use this attribute to set number of retries.
     :param verify_ssl: Use this to specify if ssl should be verified.
     :param vault_root_token_id: Use this for the root token id for vault.
+    :param vault_approle_role_id: Use this for the approle role_id for vault.
+    :param vault_approle_secret_id: Use this for the approle secret_id
+                                    for vault.
+    :param vault_kv_mountpoint: Mountpoint of KV store in vault to use.
     :param vault_url: Use this for the url for vault.
     :param vault_use_ssl: Use this to force vault driver to use ssl.
     :param vault_ssl_ca_crt_file: Use this for the CA file for vault.
+    :param barbican_endpoint_type: Use this to specify the type of URL.
+    :                              Valid values are: public, internal or admin.
     """
     conf.register_opts(km.key_manager_opts, group='key_manager')
     if bkm:
@@ -87,11 +96,23 @@ def set_defaults(conf, backend=None, barbican_endpoint=None,
         if verify_ssl is not None:
             conf.set_default('verify_ssl', verify_ssl,
                              group=bkm.BARBICAN_OPT_GROUP)
+        if barbican_endpoint_type is not None:
+            conf.set_default('barbican_endpoint_type', barbican_endpoint_type,
+                             group=bkm.BARBICAN_OPT_GROUP)
 
     if vkm is not None:
         if vault_root_token_id is not None:
             conf.set_default('root_token_id', vault_root_token_id,
                              group=vkm.VAULT_OPT_GROUP)
+        if vault_approle_role_id is not None:
+            conf.set_default('approle_role_id', vault_approle_role_id,
+                             group=vkm.VAULT_OPT_GROUP)
+        if vault_approle_secret_id is not None:
+            conf.set_default('approle_secret_id', vault_approle_secret_id,
+                             group=vkm.VAULT_OPT_GROUP)
+        if vault_kv_mountpoint is not None:
+            conf.set_default('kv_mountpoint', vault_kv_mountpoint,
+                             group=vkm.VAULT_OPT_GROUP)
         if vault_url is not None:
             conf.set_default('vault_url', vault_url,
                              group=vkm.VAULT_OPT_GROUP)
